import MapBase from "./MapBase";
import * as Utils from "./utils";

import { connect } from "react-redux";
import { compose } from "recompose";

import mapboxgl from "mapbox-gl";

class LotMap extends MapBase {
  constructor(props) {
    super(props);
  }

  componentDidUpdate(prevProps) {
    const { lot } = this.props;
    if (lot !== prevProps.lot) {
      this.map.setCenter([lot.position._longitude, lot.position._latitude]);
      this.map.setZoom(16.5);
    }
  }

  draw() {
    const { user } = this.props;
    const { lot } = this.props;
    const lng = lot.position._longitude;
    const lat = lot.position._latitude;
    // const { lng, lat } = this.map.getCenter();
    const zoom = this.map.getZoom().toFixed(2);

    this.setState({ lng, lat, zoom, loading: true });

    if (!lot) return;

    this.map.setCenter({ lng, lat });

    var el = document.createElement('div');

    var type = Utils.getLotType(lot, user)

    el.className = 'marker';
    el.style.backgroundImage = 'url(' + Utils.bubbles_colors[type].bubble +')'
    el.style.width = 50 + 'px';
    el.style.height = 50 + 'px';

    var number = document.createElement('span');
    number.className = 'marker';
    number.innerText = Object.keys(lot.cells).length

    el.appendChild(number);

    new mapboxgl.Marker(el)
        .setLngLat([
          lot.position._longitude,
          lot.position._latitude
        ])
        .addTo(this.map);

    this.setState({ loading: false });
  }

  onMapLoad() {
    this.draw();
  }

  onMapMoveEnd(data) {
    // this.draw();
  }
}

const mapStateToProps = state => {
  const { authUser } = state.session;
  return { user: authUser };
};

export default compose(
  connect(
    mapStateToProps,
  )
)(LotMap);
