import React, { Fragment } from "react";
import mapboxgl from "mapbox-gl";

mapboxgl.accessToken =
  "pk.eyJ1IjoibWFwYm94IiwiYSI6ImNpejY4M29iazA2Z2gycXA4N2pmbDZmangifQ.-g_vE53SD2WrJ6tFX7QHmA";

const DEFAULT_STATE = {
  lng: 37.635308,
  lat: 55.737694,
  zoom: 16,
  loading: false
};

const MAX_ZOOM = 18;
const MIN_ZOOM = 3;

class MapBase extends React.Component {
  constructor(props) {
    super(props);

    this.state = { ...DEFAULT_STATE };
  }

  onMapLoad() {
    console.log("MAP WAS LOADED");
  }
  onMapMoveEnd(data) {
    console.log("MAP MOVE ENDED", data);
  }

  componentDidMount() {
    const { lng, lat, zoom } = this.state;

    this.map = new mapboxgl.Map({
      container: this.mapContainer,
      style: "mapbox://styles/mapbox/streets-v11",
      maxZoom: MAX_ZOOM,
      minZoom: MIN_ZOOM,
      center: [lng, lat],
      zoom
    });

    this.map.on("load", this.onMapLoad.bind(this));

    this.map.on("moveend", this.onMapMoveEnd.bind(this));
  }

  render() {
    const { lng, lat, zoom, loading } = this.state;
    const { style = {} } = this.props;
    const informer = false;
    return (
      <Fragment>
        <div
          className={`flex-1 map-container${loading ? " loading" : ""}`}
          style={{ ...style, position: "relative" }}
          ref={el => (this.mapContainer = el)}
        >
          {informer && (
            <div
              className="informer"
              style={{ zIndex: 999 }}
            >{`Longitude: ${lng} Latitude: ${lat} Zoom: ${zoom}`}</div>
          )}
        </div>
      </Fragment>
    );
  }
}

export default MapBase;
