import React from "react";
import { Form, Message, Segment } from "semantic-ui-react";

import { connect } from "react-redux";

import { charge, error, ReturnStatus } from "../../reducers/stripe";
import "./PaymentForm.scss";

const mapStateToProps = state => state.stripe;

const mapDispatchToProps = dispatch => ({
  //  onLoadCurrency: (base) => dispatch(loadCurrency(base))
  onSubmit: (userID, dataJson, options) =>
    dispatch(charge(userID, dataJson, options)),
  onSetError: (body, header) => dispatch(error(body, header)),
  onClearError: () => dispatch(error()),
  setPaymentStatus: status => dispatch(ReturnStatus(status))
});

//import Stripe from 'stripe';
if (window.Stripe === undefined) {
  const script = document.createElement("script");
  script.src = "https://js.stripe.com/v3/";
  script.async = true;
  document.body.appendChild(script);
}

var stripe = window.Stripe("pk_test_pKMc6Ygwt2wzQCxHc8Zx4nAw");

const elementClasses = {
  base: "ui white message",
  invalid: "ui red message",
  complete: "ui green message"
};

var elementStyles = {};

class PaymentForm extends React.Component {
  constructor(props) {
    super(props);

    var elements = stripe.elements();

    this.handleCvcChange = this.handleCvcChange.bind(this);
    this.handleExpiryChange = this.handleExpiryChange.bind(this);
    this.handleNumberChange = this.handleNumberChange.bind(this);

    this.handleBeforeSubmit = this.handleBeforeSubmit.bind(this);

    this.cardNumber = elements.create("cardNumber", {
      style: elementStyles,
      classes: elementClasses
    });

    this.cardExpiry = elements.create("cardExpiry", {
      style: elementStyles,
      classes: elementClasses
    });

    this.cardCvc = elements.create("cardCvc", {
      style: elementStyles,
      classes: elementClasses
    });
    //

    // this.card = elements.create("card", { classes: elementClasses });
    this.cardCvc.addEventListener("change", this.handleCvcChange);
    this.cardExpiry.addEventListener("change", this.handleExpiryChange);
    this.cardNumber.addEventListener("change", this.handleNumberChange);
  }

  handleChange(event) {
    const target = event.target;
    const value = target.type === "checkbox" ? target.checked : target.value;
    const name = target.name;

    this.setState({
      [name]: value
    });
  }

  /**
   * проверяем ввод CVC
   * @param {*} event
   */
  handleCvcChange(event) {
    if (event.error !== undefined) {
      this.props.onSetError(event.error.message);
    } else {
      this.props.onClearError();
    }
  }

  /**
   * проверяем номер карты
   * @param {*} event
   */
  handleExpiryChange(event) {
    if (event.error !== undefined) {
      this.props.onSetError(event.error.message);
    } else {
      this.props.onClearError();
    }
  }

  /**
   * проверяем номер карты
   * @param {*} event
   */
  handleNumberChange(event) {
    if (event.error !== undefined) {
      this.props.onSetError(event.error.message);
    } else {
      this.props.onClearError();
    }
  }
  // перед отправкой формы
  handleBeforeSubmit(event) {
    event.preventDefault();

    const sum = parseInt(event.target.dataset.value, 10) * 100;

    let parent = this;
    // здесь получаем токен и возвращаем его на сервер
    stripe.createToken(parent.cardCvc).then(function(result) {
      if (result.error) {
        error(result.error.message);
        // errorElement.textContent = result.error.message;
      } else {
        // Send the token to your server.
        parent.stripeTokenHandler(result.token, sum);
      }
    });
  }

  // Submit the form with the token ID.
  stripeTokenHandler(token, sum) {
    const { onSubmit, userID, onReadyUrl } = this.props;

    // Insert the token ID into the form so it gets submitted to the server
    var form = document.getElementById("payment-form");
    var hiddenInput = document.createElement("input");
    hiddenInput.setAttribute("type", "hidden");
    hiddenInput.setAttribute("name", "stripeToken");
    hiddenInput.setAttribute("value", token.id);
    form.appendChild(hiddenInput);

    // let amount = document.getElementsByName("amount")[0].value;
    let billing_name = document.getElementsByName("billing_name")[0].value;

    // получаем информацию для отправки на сервер
    let jsonData = {
      stripe_token: token.id,
      amount: sum, // хардходим токен
      billing_name: billing_name
    };

    onSubmit(
      userID,
      { ...jsonData, onReadyUrl },
      { stripe, cardNumber: this.cardNumber }
    );

    // Submit the form
    // form.submit();
  }

  componentDidMount() {
    // подключаем форму
    this.cardNumber.mount("#card-number");
    this.cardExpiry.mount("#card-expiry");
    this.cardCvc.mount("#card-cvc");
  }

  render() {
    let errTag;
    const {
      status,
      loading,
      error,
      error_message,
      setPaymentStatus
    } = this.props;

    if (error) {
      errTag = (
        <Message negative>
          <Message.Header>{error_message.header}</Message.Header>
          <p>{error_message.body}</p>
        </Message>
      );
    }

    if (status !== undefined) {
      // открываем окно, и закрываем текущее окно
      // const w = window.open(
      //   "avvyland://payment/" + status,
      //   "_blank",
      //   "width=0,height=0"
      // );
      // w.close();
      document.location.href = "avvyland://payment/" + status;
      setPaymentStatus(undefined);

      // return null;
    }

    return (
      <React.Fragment>
        <h3>Pay with card</h3>
        <Segment>
          <Form id="payment-form">
            <Form.Input
              id="form-subcomponent-shorthand-input-billing-name"
              name="billing_name"
              label="Billing name"
              placeholder="Billing name"
              // onChange={this.handleChange}
            />

            <Form.Field>
              <label>Card</label>
              <div id="card-number" />
            </Form.Field>

            <Form.Group widths="equal">
              <Form.Field>
                <div id="card-expiry" />
              </Form.Field>

              <Form.Field>
                <div id="card-cvc" />
              </Form.Field>
            </Form.Group>

            {errTag}

            <Form.Group widths="equal">
              <Form.Button
                fluid
                primary
                loading={loading}
                onClick={this.handleBeforeSubmit}
                data-value={5}
              >
                Pay 5$
              </Form.Button>
              <Form.Button
                fluid
                primary
                loading={loading}
                onClick={this.handleBeforeSubmit}
                data-value={10}
              >
                Pay 10$
              </Form.Button>
              <Form.Button
                fluid
                primary
                loading={loading}
                onClick={this.handleBeforeSubmit}
                data-value={50}
              >
                Pay 50$
              </Form.Button>
              <Form.Button
                fluid
                primary
                loading={loading}
                onClick={this.handleBeforeSubmit}
                data-value={100}
              >
                Pay 100$
              </Form.Button>
            </Form.Group>

            {/* <Form.Input
            action={{
              color: "teal",
              labelPosition: "left",
              icon: "cart",
              content: "Checkout",
              onClick: e => this.handleBeforeSubmit(e)
            }}
            loading={loading}
            name="amount"
            onChange={this.handleChange}
            actionPosition="left"
            placeholder="Amount..."
          /> */}
          </Form>
        </Segment>
      </React.Fragment>
    );
  }
}

export default connect(
  mapStateToProps,
  mapDispatchToProps
)(PaymentForm);
