import React from "react";
import { connect } from "react-redux";
import { compose } from "recompose";
import { withFirebase } from "../../../components/Firebase";
import { Button, Label } from "semantic-ui-react";

import * as ACTIONS from "../../../actions/lot";
// import { setCurrentLot } from "../../../actions/lot";

class OfferButton extends React.Component {
  constructor(props) {
    super(props);

    this.state = {
      value: Math.max(parseFloat(props.value || 0) / 100, 0).toFixed(2)
    };
  }

  onclick(e) {
    const {
      firebase,
      lot,
      status,
      priceField,
      setLotStatusStart,
      setLotStatusSuccess,
      setLotStatusError
    } = this.props;
    const { value } = this.state;

    if (e.target.tagName === "INPUT") return false;
    e.preventDefault();
    setLotStatusStart();
    firebase
      .setLotStatus({
        lotid: lot.uid,
        status,
        [priceField]: parseInt(value * 100, 10)
      })
      .then(response => {
        try {
          const data = JSON.parse(response.data.lot)[lot.uid];
          setLotStatusSuccess({ ...data, uid: lot.uid });
        } catch (error) {
          setLotStatusError(error);
        }
      })
      .catch(error => {
        setLotStatusError(error);
      });
  }

  validate(e) {
    const value = (Math.max(parseFloat(e.target.value) * 100, 0) / 100).toFixed(
      2
    );
    this.setState({ value });
  }

  render() {
    const { color, buttonText, fieldLabel, min = 0 } = this.props;
    const { value } = this.state;
    return (
      <Button
        className="offer_button"
        as="div"
        labelPosition="right"
        onClick={this.onclick.bind(this)}
      >
        <button
          className={`ui button${fieldLabel ? " sub_text" : ""}`}
          style={{
            backgroundColor: color,
            color: "#FFF"
          }}
        >
          <div className="btn_text">{buttonText}</div>
          {fieldLabel && <div className="btn_sub_text">{fieldLabel}</div>}
        </button>
        <Label as="a" basic pointing="left" style={{ borderColor: color }}>
          <div>
            <div className="ui left icon input">
              <input
                type="number"
                value={value}
                onChange={this.validate.bind(this)}
                min={min}
              />
              <i aria-hidden="true" className="dollar sign icon" />
            </div>
            {/* {fieldLabel && <span style={{ marginLeft: 10 }}>{fieldLabel}</span>} */}
          </div>
        </Label>
      </Button>
    );
  }
}

const mapStateToProps = state => {
  const { currentLot } = state.lot;

  return { lot: currentLot };
};
const mapDispatchToProps = dispatch => ({
  setLotStatusStart: () => dispatch(ACTIONS.setLotStatusStart()),
  setLotStatusSuccess: data => dispatch(ACTIONS.setLotStatusSuccess(data)),
  setLotStatusError: error => dispatch(ACTIONS.setLotStatusError(error))
});

export default compose(
  withFirebase,
  connect(
    mapStateToProps,
    mapDispatchToProps
  )
)(OfferButton);
