import React, { Fragment } from "react";
import { connect } from "react-redux";
import { compose } from "recompose";
import { withFirebase } from "../../../components/Firebase";

import { Button, Label } from "semantic-ui-react";

import * as ACTIONS from "../../../actions/lot";

import * as FORMAT from "../../../utils/Formater";

class RentButton extends React.Component {
  constructor(props) {
    super(props);
    this.state = {
      days: 0,
      min: 0,
      max: 0,
      Balance: 0,
      rentPrice: 0,
      total: 0
    };
  }

  componentDidMount() {
    const { authUser, lot } = this.props;
    const { Balance } = authUser;
    const { rentPrice } = lot;
    const max = Math.floor(Balance / rentPrice);
    const min = max ? 1 : 0;
    const days = min;
    const total = days * rentPrice;
    this.setState({ Balance, min, max, rentPrice, days, total });
  }

  onclick(e) {
    const {
      firebase,
      lot,
      setLotStatusStart,
      setLotStatusSuccess,
      setLotStatusError
    } = this.props;
    const { days } = this.state;

    if (e.target.tagName === "INPUT") return false;
    e.preventDefault();

    setLotStatusStart();
    firebase
      .rentLot({ lotid: lot.uid, period: days })
      .then(response => {
        try {
          const data = JSON.parse(response.data.lots)[lot.uid];
          setLotStatusSuccess({ ...data, uid: lot.uid });
        } catch (error) {
          setLotStatusError(error);
        }
      })
      .catch(error => {
        setLotStatusError(error);
      });
  }

  onchange(e) {
    const days = e.target.value;
    const { rentPrice } = this.state;
    const total = days * rentPrice;
    this.setState({ days, total });
  }

  render() {
    const { color } = this.props;
    const { days, min, max, total, rentPrice } = this.state;
    return (
      <Fragment>
        <Button
          as="div"
          labelPosition="right"
          onClick={this.onclick.bind(this)}
        >
          <Button color={color}>Rent</Button>
          <Label as="a" basic color={color} pointing="left">
            <div style={{ whiteSpace: "nowrap" }}>{`${FORMAT.money(
              rentPrice
            )} per day`}</div>
            <input
              type="range"
              min={min}
              max={max}
              value={days}
              step="1"
              onChange={this.onchange.bind(this)}
              style={{ margin: "0 20px" }}
            />
            <div style={{ whiteSpace: "nowrap" }}>{`${FORMAT.plural(
              days,
              "day"
            )} for ${FORMAT.money(total)}`}</div>
          </Label>
        </Button>
        <div />
      </Fragment>
    );
  }
}

const mapStateToProps = (state /*, ownProps*/) => {
  const { authUser } = state.session;
  const { currentLot } = state.lot;

  return { authUser, lot: currentLot };
};
const mapDispatchToProps = dispatch => ({
  setLotStatusStart: () => dispatch(ACTIONS.setLotStatusStart()),
  setLotStatusSuccess: data => dispatch(ACTIONS.setLotStatusSuccess(data)),
  setLotStatusError: error => dispatch(ACTIONS.setLotStatusError(error))
});

export default compose(
  withFirebase,
  connect(
    mapStateToProps,
    mapDispatchToProps
  )
)(RentButton);
