import React, { Component } from "react";
import { Redirect, withRouter } from "react-router-dom";
import { connect } from "react-redux";
import { compose } from "recompose";
import { Form, Message, Button, Image, Divider } from "semantic-ui-react";

// import { SignUpLink } from "../SignUp";
import { PasswordForgetLink } from "../PasswordForget";
import { withFirebase } from "../../components/Firebase";
import * as ROUTES from "../../constants/routes";

import { setActiveRoute } from "../../actions/page";

import "./SignIn.scss";

class SignInPage extends Component {
  componentWillMount() {
    const { setActiveRoute } = this.props;
    setActiveRoute(ROUTES.SIGN_IN);
  }

  render() {
    const { authUser } = this.props;

    if (authUser) {
      return <Redirect to={ROUTES.HOME} />;
    }

    return (
      <div className="signin">
        <div className="signin_container">
          <div className="signin_image">
            <Image src="/images/PhoneLogo2.png" />
          </div>
          <div className="signin_content">
            <div className="signin_form">
              <Image src="/images/AvvyLandTitle.svg" />
              <SignInForm />
              <Divider horizontal>OR</Divider>
              <PasswordForgetLink />
            </div>
            <div className="signin_store">
              <div>Don't have an account? Get the app.</div>
              <div className="signin_store_apps">
                <Image src="/images/AppleStoreLogo.png" />
                <Image src="/images/GoogleStoreLogo.png" />
              </div>
            </div>
          </div>
        </div>
      </div>
    );
  }
}

const mapStateToProps = state => {
  const { authUser } = state.session;
  return { authUser };
};

const mapDispatchToProps = dispatch => ({
  setActiveRoute: route => dispatch(setActiveRoute(route))
});

export default compose(
  withRouter,
  connect(
    mapStateToProps,
    mapDispatchToProps
  )
)(SignInPage);

const INITIAL_STATE = {
  email: "",
  password: "",
  error: null
};

class SignInFormBase extends Component {
  constructor(props) {
    super(props);

    this.state = { ...INITIAL_STATE };
  }

  onSubmit = event => {
    const { email, password } = this.state;

    this.props.firebase
      .doSignInWithEmailAndPassword(email, password)
      .then(() => {
        this.setState({ ...INITIAL_STATE });
        this.props.history.push(ROUTES.HOME);
      })
      .catch(error => {
        this.setState({ error });
      });

    event.preventDefault();
  };

  onChange = event => {
    this.setState({ [event.target.name]: event.target.value });
  };

  render() {
    const { email, password, error } = this.state;

    const isInvalid = password === "" || email === "";

    return (
      <Form className="ui form" onSubmit={this.onSubmit}>
        <Form.Input
          placeholder="E-mail Address"
          type="text"
          name="email"
          onChange={this.onChange}
          value={email}
        />
        <Form.Input
          placeholder="Password"
          type="password"
          name="password"
          onChange={this.onChange}
          value={password}
        />
        <Button fluid primary disabled={isInvalid} type="submit">
          Sign In
        </Button>

        {error && <ErrorMsg msg={error.message} />}
      </Form>
    );
  }
}

const ErrorMsg = ({ msg }) => (
  <Message negative>
    <b>{msg}</b>
  </Message>
);

const SignInForm = compose(
  withRouter,
  withFirebase
)(SignInFormBase);

export { SignInForm };
